@@ -81,13 +81,13 @@ class V1Operation(BaseOp, polyaxon_sdk.V1Operation):
     connections, and a run environment.
 
     With an operation users can:
-     * pass the parameters for required inputs or override the default values of optional inputs.
-     * patch the definition of the component to set environments, initializers, and resources.
-     * set termination logic and retries.
-     * set trigger logic to start a component in a pipeline context.
-     * parallelize or map the component over a matrix of parameters.
-     * put an operation on a schedule.
-     * subscribe a component to events to trigger executions automatically.
+     * Pass the parameters for required inputs or override the default values of optional inputs.
+     * Patch the definition of the component to set environments, initializers, and resources.
+     * Set termination logic and retries.
+     * Set trigger logic to start a component in a pipeline context.
+     * Parallelize or map the component over a matrix of parameters.
+     * Put an operation on a schedule.
+     * Subscribe a component to events to trigger executions automatically.
 
     Args:
         version: str
@@ -353,9 +353,9 @@ class V1Operation(BaseOp, polyaxon_sdk.V1Operation):
     >>>     ]
     ```
 
-    This component is generic, and does not define resource requirements,
+    This component is generic, and does not define resources requirements,
     if for instance this component is hosted on github and you don't
-    want to modify the component while on the sametime you want to request a GPU for the notebook,
+    want to modify the component while at the sametime you want to request a GPU for the notebook,
     you can patch the run:
 
     ```yaml
