@@ -18,7 +18,10 @@ from typing import Any, Dict, Iterable, Optional
 
 from kubernetes import client as k8s_client
 
-from polyaxon.containers import V1PolyaxonInitContainer, V1PolyaxonSidecarContainer
+from polyaxon.containers.containers import (
+    V1PolyaxonInitContainer,
+    V1PolyaxonSidecarContainer,
+)
 from polyaxon.exceptions import PolyaxonCompilerError
 from polyaxon.polyflow import V1CompiledOperation
 from polyaxon.polypod.compiler.converters import CORE_CONVERTERS
@@ -44,7 +47,7 @@ def convert(
 ) -> Dict:
     if compiled_operation.has_pipeline:
         raise PolyaxonCompilerError(
-            "Specification with parallel/dag section is not supported in this function."
+            "Specification with matrix/dag section is not supported in this function."
         )
 
     run_kind = compiled_operation.get_run_kind()
