@@ -99,7 +99,7 @@ class TestWorkflowV1Dags(BaseTestCase):
                             "nodeSelector": {"polyaxon": "core"},
                             "serviceAccountName": "service",
                             "imagePullSecrets": ["secret1", "secret2"],
-                            "restartPolicy": "never",
+                            "restartPolicy": "Never",
                         },
                     },
                 },
@@ -117,7 +117,7 @@ class TestWorkflowV1Dags(BaseTestCase):
                             "nodeSelector": {"polyaxon": "core"},
                             "serviceAccountName": "service",
                             "imagePullSecrets": ["secret1", "secret2"],
-                            "restartPolicy": "never",
+                            "restartPolicy": "Never",
                         },
                     },
                 },
@@ -168,7 +168,7 @@ class TestWorkflowV1Dags(BaseTestCase):
                             "nodeSelector": {"polyaxon": "core"},
                             "serviceAccountName": "service",
                             "imagePullSecrets": ["secret1", "secret2"],
-                            "restartPolicy": "never",
+                            "restartPolicy": "Never",
                         },
                         "container": {
                             "resources": {"requests": {"cpu": "500m"}},
@@ -202,7 +202,7 @@ class TestWorkflowV1Dags(BaseTestCase):
                             "nodeSelector": {"polyaxon": "core"},
                             "serviceAccountName": "service",
                             "imagePullSecrets": ["secret1", "secret2"],
-                            "restartPolicy": "never",
+                            "restartPolicy": "Never",
                         },
                     },
                     "component": {
@@ -331,7 +331,7 @@ class TestWorkflowV1Dags(BaseTestCase):
         assert config.dag["D"].upstream == {"B", "C"}
         assert config.dag["D"].downstream == set()
 
-    def test_dag_parallel_ops(self):
+    def test_dag_matrix_ops(self):
         config_dict = {
             "kind": V1RunKind.DAG,
             "operations": [
